Store<S extends State, A extends Action, AC extends ActionCreator<Action>> class
abstract
Constructors
-
Store({required S initialState})
-
Properties
-
hashCode
→ int
-
The hash code for this object.
no setterinherited
-
runtimeType
→ Type
-
A representation of the runtime type of the object.
no setterinherited
-
stream
→ Stream<S>
-
no setter
Methods
-
dispose()
→ void
-
-
noSuchMethod(Invocation invocation)
→ dynamic
-
Invoked when a nonexistent method or property is accessed.
inherited
-
reduce(S currentState, A action)
→ S
-
-
toString()
→ String
-
A string representation of this object.
inherited